# usernetes (python)

> Python SDK and client to deploy user space Kubernetes (usernetes)

[![PyPI version](https://badge.fury.io/py/usernetes.svg)](https://badge.fury.io/py/usernetes)

This is a library in Python to easily deploy [Usernetes](https://github.com/rootless-containers/usernetes).
It is implemented in Python anticipating being used by Flux Framework, which has the most feature rich SDK
written in Python.

⭐️ [Documentation](https://converged-compyuting.github.io/usernetes-python) ⭐️

## License

HPCIC DevTools is distributed under the terms of the MIT license.
All new contributions must be made under this license.

See [LICENSE](https://github.com/converged-computing/cloud-select/blob/main/LICENSE),
[COPYRIGHT](https://github.com/converged-computing/cloud-select/blob/main/COPYRIGHT), and
[NOTICE](https://github.com/converged-computing/cloud-select/blob/main/NOTICE) for details.

SPDX-License-Identifier: (MIT)

LLNL-CODE- 842614
